@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: Cns_main.c,v $ $Revision: 4497 $ $Date: 2011-06-20 18:37:21 +0200 (Mon, 20 Jun 2011) $ CERN IT-PDP/DM Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: Cns_main.c,v $ $Revision: 6490 $ $Date: 2012-06-25 16:20:06 +0200 (Mon, 25 Jun 2012) $ CERN IT-PDP/DM Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <errno.h>
@@ -170,6 +170,9 @@ struct main_args *main_args;
 	if (MsgProd_Init_cfgfile(getenv("SEMSGCONFIGFILE"))) {
 		nslogit (func, "Trouble initializing the SEMsg C producer (cfgfile: %s)\n", getenv("SEMSGCONFIGFILE"));
 	}
+	else {
+		nslogit (func, "SEMsg C producer was correctly initialized (cfgfile: %s)\n", getenv("SEMSGCONFIGFILE"));
+	}
 #endif
 
 
