@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: send2nsd.c,v $ $Revision: 4529 $ $Date: 2011-06-24 10:44:50 +0200 (Fri, 24 Jun 2011) $ CERN IT-PDP/DM Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: send2nsd.c,v $ $Revision: 6571 $ $Date: 2012-07-03 17:12:11 +0200 (Tue, 03 Jul 2012) $ CERN IT-PDP/DM Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <errno.h>
@@ -18,6 +18,7 @@ static char sccsid[] = "@(#)$RCSfile: send2nsd.c,v $ $Revision: 4529 $ $Date: 20
 #include <netdb.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
+#include <netinet/tcp.h>
 #endif
 #include "Cnetdb.h"
 #include "Cns.h"
@@ -90,6 +91,7 @@ int *nbstruct;
 	char strport[NI_MAXSERV];
 	struct Cns_api_thread_info *thip = NULL;
 	int timeout;
+	int yes = 1;
 
 	strcpy (func, "send2nsd");
 	if (socketp && *socketp >= 0) {	/* connection opened by Cns_list... */
@@ -99,7 +101,7 @@ int *nbstruct;
 	} else {			/* connection not yet opened */
 		if (host && *host)
 			strcpy (Cnshost, host);
-		else if ((p = getenv (CNS_HOST_ENV)) || (p = getconfent (CNS_SCE, "HOST", 0)))
+		else if ((p = Cns_getenv (CNS_HOST_ENV)) || (p = getconfent (CNS_SCE, "HOST", 0)))
 			strcpy (Cnshost, p);
 		else {
 #if defined(CNS_HOST)
@@ -121,7 +123,7 @@ int *nbstruct;
 			strncpy (strport, p+1, sizeof(strport));
 			strport[sizeof(strport)-1] = '\0';
 		} else {
-			if ((p = getenv (CNS_PORT_ENV)) || (p = getconfent (CNS_SCE, "PORT", 0))) {
+			if ((p = Cns_getenv (CNS_PORT_ENV)) || (p = getconfent (CNS_SCE, "PORT", 0))) {
 				strncpy (strport, p, sizeof(strport));
 				strport[sizeof(strport)-1] = '\0';
 			} else {
@@ -151,19 +153,19 @@ int *nbstruct;
 		}
 
 		/* get retry environment variables */
-		if ((p = getenv (CNS_CONNTIMEOUT_ENV)) == NULL) {
+		if ((p = Cns_getenv (CNS_CONNTIMEOUT_ENV)) == NULL) {
 			timeout = DEFAULT_CONNTIMEOUT;
 		} else {
 			timeout = atoi (p);
 		}
 
-		if ((p = getenv (CNS_CONRETRY_ENV)) == NULL) {
+		if ((p = Cns_getenv (CNS_CONRETRY_ENV)) == NULL) {
 			nbretry = DEFAULT_RETRYCNT;
 		} else {
 			nbretry = atoi(p);
 		}
 
-		if ((p = getenv (CNS_CONRETRYINT_ENV)) == NULL) {
+		if ((p = Cns_getenv (CNS_CONRETRYINT_ENV)) == NULL) {
 			retryint = RETRYI;
 		} else {
 			retryint = atoi(p);
@@ -255,8 +257,12 @@ int *nbstruct;
 					Cns_errmsg (func, NS002, "send", "Operation timed out");
 					break;
 				default:
-					Cns_errmsg (func, NS002, "send", Csec_getErrorMessageSummary (PRTBUFSZ-48));
+					{
+					char *err_buffer = Csec_getErrorMessageSummary (PRTBUFSZ-48);
+					Cns_errmsg (func, NS002, "send", err_buffer);
+					free(err_buffer);
 					abortconnect = 1;
+					}
 					break;
 			}
 
@@ -353,6 +359,9 @@ int *nbstruct;
 			serrno = SECOMERR;
 			return (-1);
 		}
+		#if defined (linux) 
+		(void) setsockopt (s, IPPROTO_TCP, TCP_QUICKACK, (char*)&yes, sizeof(int));
+		#endif
 		p = repbuf;
 		if (rep_type == MSG_ERR) {
 			unmarshall_STRING (p, prtbuf);
